pub enum TimeoutType {
Wait,
Connect,
Reuse,
}Expand description
Possible steps causing the timeout in an error returned by Client::get()
method.
Variants
Wait
Timeout happened while waiting for a slot to become available.
Connect
Timeout happened while creating a new connection.
Reuse
Timeout happened while recycling an connection.