pub trait Multiplex {
// Provided methods
fn is_multiplexed(&self) -> bool { ... }
fn fork_connection(&self) -> Option<Self>
where Self: Sized { ... }
}Expand description
Should be implemented for Connector::Connection if it supports multiplexing,
like HTTP/2. The client will retain one connection in the Pool
at all times and use the fork_connection method to create handles
to the underlying connection. Use the purge funtion on PooledConnection
when you want to remove this resource from the pool
Provided Methods
Sourcefn is_multiplexed(&self) -> bool
fn is_multiplexed(&self) -> bool
Should return True
Sourcefn fork_connection(&self) -> Option<Self>where
Self: Sized,
fn fork_connection(&self) -> Option<Self>where
Self: Sized,
Creates a new connection to the underlying multiplexed connection